"use strict";
var core_1 = require('@angular/core');
var tooltip_container_component_1 = require('./tooltip-container.component');
var tooltip_config_1 = require('./tooltip.config');
var component_loader_1 = require('../component-loader');
var TooltipDirective = (function () {
    // tslint:disable-next-line
    function TooltipDirective(_viewContainerRef, _renderer, _elementRef, cis, config) {
        /** @deprecated */
        this._animation = true;
        this._delay = 0;
        /** @deprecated */
        this._fadeDuration = 150;
        /* tslint:enable */
        this.tooltipStateChanged = new core_1.EventEmitter();
        this._tooltip = cis
            .createLoader(_elementRef, _viewContainerRef, _renderer);
        Object.assign(this, config);
        this.onShown = this._tooltip.onShown;
        this.onHidden = this._tooltip.onHidden;
    }
    Object.defineProperty(TooltipDirective.prototype, "isOpen", {
        /**
         * Returns whether or not the tooltip is currently being shown
         */
        get: function () { return this._tooltip.isShown; },
        set: function (value) {
            if (value) {
                this.show();
            }
            else {
                this.hide();
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TooltipDirective.prototype, "htmlContent", {
        /* tslint:disable */
        /** @deprecated */
        set: function (value) {
            console.warn('tooltipHtml was deprecated, please use `tooltip` instead');
            this.tooltip = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TooltipDirective.prototype, "_placement", {
        /** @deprecated */
        set: function (value) {
            console.warn('tooltipPlacement was deprecated, please use `placement` instead');
            this.placement = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TooltipDirective.prototype, "_isOpen", {
        get: function () {
            console.warn('tooltipIsOpen was deprecated, please use `isOpen` instead');
            return this.isOpen;
        },
        /** @deprecated */
        set: function (value) {
            console.warn('tooltipIsOpen was deprecated, please use `isOpen` instead');
            this.isOpen = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TooltipDirective.prototype, "_enable", {
        get: function () {
            console.warn('tooltipEnable was deprecated, please use `isDisabled` instead');
            return this.isDisabled === true;
        },
        /** @deprecated */
        set: function (value) {
            console.warn('tooltipEnable was deprecated, please use `isDisabled` instead');
            this.isDisabled = value === true;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TooltipDirective.prototype, "_appendToBody", {
        get: function () {
            console.warn('tooltipAppendToBody was deprecated, please use `container="body"` instead');
            return this.container === 'body';
        },
        /** @deprecated */
        set: function (value) {
            console.warn('tooltipAppendToBody was deprecated, please use `container="body"` instead');
            this.container = value ? 'body' : this.container;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TooltipDirective.prototype, "_popupClass", {
        /** @deprecated */
        set: function (value) {
            console.warn('tooltipClass deprecated');
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TooltipDirective.prototype, "_tooltipContext", {
        /** @deprecated */
        set: function (value) {
            console.warn('tooltipContext deprecated');
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TooltipDirective.prototype, "_tooltipTrigger", {
        /** @deprecated */
        get: function () {
            console.warn('tooltipTrigger was deprecated, please use `triggers` instead');
            return this.triggers;
        },
        set: function (value) {
            console.warn('tooltipTrigger was deprecated, please use `triggers` instead');
            this.triggers = (value || '').toString();
        },
        enumerable: true,
        configurable: true
    });
    ;
    ;
    TooltipDirective.prototype.ngOnInit = function () {
        var _this = this;
        this._tooltip.listen({
            triggers: this.triggers,
            show: function () { return _this.show(); }
        });
    };
    TooltipDirective.prototype.show = function () {
        var _this = this;
        if (this._tooltip.isShown || this.isDisabled || this._delayTimeoutId) {
            return;
        }
        var showTooltip = function () { return _this._tooltip
            .attach(tooltip_container_component_1.TooltipContainerComponent)
            .to(_this.container)
            .position({ attachment: _this.placement })
            .show(_this.tooltip, {
            placement: _this.placement,
            title: _this.tooltipTitle
        }); };
        if (this._delay) {
            this._delayTimeoutId = setTimeout(function () { showTooltip(); }, this._delay);
        }
        else {
            showTooltip();
        }
    };
    TooltipDirective.prototype.hide = function () {
        var _this = this;
        if (this._delayTimeoutId) {
            clearTimeout(this._delayTimeoutId);
            this._delayTimeoutId = undefined;
        }
        if (!this._tooltip.isShown) {
            return;
        }
        this._tooltip.instance.classMap.in = false;
        setTimeout(function () {
            _this._tooltip.hide();
        }, this._fadeDuration);
    };
    TooltipDirective.prototype.ngOnDestroy = function () {
        this._tooltip.dispose();
    };
    TooltipDirective.decorators = [
        { type: core_1.Directive, args: [{
                    selector: '[tooltip], [tooltipHtml]',
                    exportAs: 'bs-tooltip'
                },] },
    ];
    /** @nocollapse */
    TooltipDirective.ctorParameters = [
        { type: core_1.ViewContainerRef, },
        { type: core_1.Renderer, },
        { type: core_1.ElementRef, },
        { type: component_loader_1.ComponentLoaderFactory, },
        { type: tooltip_config_1.TooltipConfig, },
    ];
    TooltipDirective.propDecorators = {
        'tooltip': [{ type: core_1.Input },],
        'tooltipTitle': [{ type: core_1.Input },],
        'placement': [{ type: core_1.Input },],
        'triggers': [{ type: core_1.Input },],
        'container': [{ type: core_1.Input },],
        'isOpen': [{ type: core_1.Input },],
        'isDisabled': [{ type: core_1.Input },],
        'onShown': [{ type: core_1.Output },],
        'onHidden': [{ type: core_1.Output },],
        'htmlContent': [{ type: core_1.Input, args: ['tooltipHtml',] },],
        '_placement': [{ type: core_1.Input, args: ['tooltipPlacement',] },],
        '_isOpen': [{ type: core_1.Input, args: ['tooltipIsOpen',] },],
        '_enable': [{ type: core_1.Input, args: ['tooltipEnable',] },],
        '_appendToBody': [{ type: core_1.Input, args: ['tooltipAppendToBody',] },],
        '_animation': [{ type: core_1.Input, args: ['tooltipAnimation',] },],
        '_popupClass': [{ type: core_1.Input, args: ['tooltipClass',] },],
        '_tooltipContext': [{ type: core_1.Input, args: ['tooltipContext',] },],
        '_delay': [{ type: core_1.Input, args: ['tooltipPopupDelay',] },],
        '_fadeDuration': [{ type: core_1.Input, args: ['tooltipFadeDuration',] },],
        '_tooltipTrigger': [{ type: core_1.Input, args: ['tooltipTrigger',] },],
        'tooltipStateChanged': [{ type: core_1.Output },],
    };
    return TooltipDirective;
}());
exports.TooltipDirective = TooltipDirective;
